@@ -30,11 +30,11 @@ class Sin(UnaryUfunc):
 
 def _dsinc(x):
     x = x * np.pi
-    return (x * np.cos(x) - np.sin(x)) / x ** 2
+    return (x * np.cos(x) - np.sin(x)) / x**2
 
 
 class Sinc(Operation):
-    """ f(a) -> sin(pi*a)/(pi*a)"""
+    """f(a) -> sin(pi*a)/(pi*a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -43,7 +43,12 @@ class Sinc(Operation):
     def backward_var(self, grad, index, **kwargs):
         (a,) = self.variables
         x = a.data
-        return np.pi * grad * np.piecewise(x, [x == 0, x != 0], [np.zeros_like, _dsinc])
+
+        # TODO: use tiny
+        near_0 = np.isclose(x, 0, atol=1e-20)
+        return (
+            np.pi * grad * np.piecewise(x, [near_0, ~near_0], [np.zeros_like, _dsinc])
+        )
 
 
 class Cos(UnaryUfunc):
@@ -63,7 +68,7 @@ class Tan(UnaryUfunc):
 
 
 class Csc(Operation):
-    """ f(a) -> csc(a)"""
+    """f(a) -> csc(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -75,7 +80,7 @@ class Csc(Operation):
 
 
 class Sec(Operation):
-    """ f(a) -> sec(a)"""
+    """f(a) -> sec(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -87,7 +92,7 @@ class Sec(Operation):
 
 
 class Cot(Operation):
-    """ f(a) -> cot(a)"""
+    """f(a) -> cot(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -104,7 +109,7 @@ class Arcsin(UnaryUfunc):
     def backward_var(self, grad, index, **kwargs):
         # d arcsin / dx at x = -1, 1 returns 0, not NaN
         (a,) = self.variables
-        return np.select([np.abs(a.data) != 1], [grad / np.sqrt(1 - a.data ** 2)])
+        return np.select([np.abs(a.data) != 1], [grad / np.sqrt(1 - a.data**2)])
 
 
 class Arccos(UnaryUfunc):
@@ -113,7 +118,7 @@ class Arccos(UnaryUfunc):
     def backward_var(self, grad, index, **kwargs):
         # d arccos / dx at x = -1, 1 returns 0, not NaN
         (a,) = self.variables
-        return np.select([np.abs(a.data) != 1], [-grad / np.sqrt(1 - a.data ** 2)])
+        return np.select([np.abs(a.data) != 1], [-grad / np.sqrt(1 - a.data**2)])
 
 
 class Arctan(UnaryUfunc):
@@ -121,11 +126,11 @@ class Arctan(UnaryUfunc):
 
     def backward_var(self, grad, index, **kwargs):
         (a,) = self.variables
-        return grad / (1 + a.data ** 2)
+        return grad / (1 + a.data**2)
 
 
 class Arccsc(Operation):
-    """ f(a) -> arccsc(a)"""
+    """f(a) -> arccsc(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -135,12 +140,12 @@ class Arccsc(Operation):
         # d arccsc / dx at x = -1, 1 returns 0, not NaN
         (a,) = self.variables
         return np.select(
-            [np.abs(a.data) != 1], [-grad / (np.abs(a.data) * np.sqrt(a.data ** 2 - 1))]
+            [np.abs(a.data) != 1], [-grad / (np.abs(a.data) * np.sqrt(a.data**2 - 1))]
         )
 
 
 class Arcsec(Operation):
-    """ f(a) -> arcsec(a)"""
+    """f(a) -> arcsec(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -150,12 +155,12 @@ class Arcsec(Operation):
         # d arcsec / dx at x = -1, 1 returns 0, not NaN
         (a,) = self.variables
         return np.select(
-            [np.abs(a.data) != 1], [grad / (np.abs(a.data) * np.sqrt(a.data ** 2 - 1))]
+            [np.abs(a.data) != 1], [grad / (np.abs(a.data) * np.sqrt(a.data**2 - 1))]
         )
 
 
 class Arccot(Operation):
-    """ f(a) -> arccot(a)"""
+    """f(a) -> arccot(a)"""
 
     def __call__(self, a):
         self.variables = (a,)
@@ -169,7 +174,7 @@ class Arccot(Operation):
 
     def backward_var(self, grad, index, **kwargs):
         (a,) = self.variables
-        return -grad / (1 + a.data ** 2)
+        return -grad / (1 + a.data**2)
 
 
 class Arctan2(BinaryUfunc):
@@ -182,7 +187,7 @@ class Arctan2(BinaryUfunc):
     def backward_var(self, grad, index, **kwargs):
         a, b = self.variables
         if self.cached_denom is None:
-            self.cached_denom = a.data ** 2 + b.data ** 2
+            self.cached_denom = a.data**2 + b.data**2
 
         if index == 0:
             return grad * b.data / self.cached_denom
