@@ -2,9 +2,9 @@ from mygrad.tensor_creation.funcs import full
 
 
 def constant(*shape, value=0.0, dtype=None, constant=None):
-    """Initialize a `Tensor` of shape `shape` with a constant value.
+    """Initialize a :class:`mygrad.Tensor` of shape `shape` with a constant value.
 
-    This function is a thin wrapper around `mygrad.full`.
+    This function is a thin wrapper around ``mygrad.full``.
 
     Parameters
     ----------
@@ -15,16 +15,16 @@ def constant(*shape, value=0.0, dtype=None, constant=None):
         The value with which to fill the tensor.
 
     dtype : data-type, optional (default=None)
-        The data type of the output tensor, or None to match `value`.
+        The data type of the output tensor, or None to match ``value``.
 
     constant : bool, optional (default=False)
-        If `True`, the returned tensor is a constant (it
+        If ``True``, the returned tensor is a constant (it
             does not back-propagate a gradient).
 
     Returns
     -------
     Tensor
-        A Tensor of `value` with the given shape and dtype.
+        A Tensor of ``value`` with the given shape and dtype.
 
     Examples
     ----------
