@@ -3,14 +3,14 @@ import numpy as np
 from mygrad import Tensor
 
 
-def glorot_normal(*shape, gain=1, dtype=np.float32, constant=False):
-    r""" Initialize a `Tensor` according to the normal initialization procedure
+def glorot_normal(*shape, gain=1, dtype=np.float32, constant=None):
+    r"""Initialize a :class:`mygrad.Tensor` according to the normal initialization procedure
     described by Glorot and Bengio.
 
     Parameters
     ----------
     shape : Sequence[int]
-        The shape of the output Tensor. Note that `shape` must be at least two-dimensional.
+        The shape of the output Tensor. Note that ``shape`` must be at least two-dimensional.
 
     gain : Real, optional (default=1)
         The gain (scaling factor) to apply.
@@ -19,12 +19,12 @@ def glorot_normal(*shape, gain=1, dtype=np.float32, constant=False):
         The data type of the output tensor; must be a floating-point type.
 
     constant : bool, optional (default=False)
-        If `True`, the returned tensor is a constant (it
+        If ``True``, the returned tensor is a constant (it
             does not back-propagate a gradient).
 
     Returns
     -------
-    mygrad.Tensor, shape=`shape`
+    mygrad.Tensor, shape=``shape``
         A Tensor, with values initialized according to the glorot normal initialization.
 
     Notes
@@ -54,4 +54,9 @@ def glorot_normal(*shape, gain=1, dtype=np.float32, constant=False):
     fan_in = shape[1] * (shape[-1] if len(shape) > 2 else 1)
     fan_out = shape[0] * (shape[-1] if len(shape) > 2 else 1)
     std = gain * np.sqrt(2 / (fan_in + fan_out))
-    return Tensor(np.random.normal(0, std, shape), dtype=dtype, constant=constant)
+    return Tensor(
+        np.random.normal(0, std, shape),
+        dtype=dtype,
+        constant=constant,
+        copy=False,
+    )
