@@ -3,8 +3,8 @@ import numpy as np
 from mygrad.nnet.initializers.uniform import uniform
 
 
-def he_uniform(*shape, gain=1, dtype=np.float32, constant=False):
-    r""" Initialize a ``mygrad.Tensor`` according to the uniform initialization procedure
+def he_uniform(*shape, gain=1, dtype=np.float32, constant=None):
+    r"""Initialize a :class:`mygrad.Tensor` according to the uniform initialization procedure
     described by He et al.
 
     Parameters
@@ -42,7 +42,7 @@ def he_uniform(*shape, gain=1, dtype=np.float32, constant=False):
     where :math:`a` is the slope of the rectifier following this layer, which is incorporated
     using the `gain` variable above.
 
-    The guidance put forward in that paper is that this initialization procedure should be prefered
+    The guidance put forward in that paper is that this initialization procedure should be preferred
     over the ``mygrad.nnet.initializers.glorot_*`` functions especially when rectifiers (e.g. ReLU,
     PReLU, leaky_relu) in very deep (> 1-20 or so layer) networks.
 
