@@ -1,9 +1,10 @@
 import numpy as np
+
 from mygrad import Tensor
 
 
-def normal(*shape, mean=0, std=1, dtype=np.float32, constant=False):
-    """ Initialize a :class:`mygrad.Tensor` by drawing from a normal (Gaussian) distribution.
+def normal(*shape, mean=0, std=1, dtype=np.float32, constant=None):
+    """Initialize a :class:`mygrad.Tensor` by drawing from a normal (Gaussian) distribution.
 
     Parameters
     ----------
@@ -20,13 +21,13 @@ def normal(*shape, mean=0, std=1, dtype=np.float32, constant=False):
         The data type of the output tensor; must be a floating-point type.
 
     constant : bool, optional (default=False)
-        If `True`, the returned tensor is a constant (it
+        If ``True``, the returned tensor is a constant (it
             does not back-propagate a gradient).
 
     Returns
     -------
-    mygrad.Tensor, shape=`shape`
-        A Tensor, with values drawn from Ɲ(μ, σ²), where μ=`mean` and σ=`std`.
+    mygrad.Tensor, shape=``shape``
+        A Tensor, with values drawn from Ɲ(μ, σ²), where μ=``mean`` and σ=``std``.
 
     Examples
     --------
@@ -55,4 +56,9 @@ def normal(*shape, mean=0, std=1, dtype=np.float32, constant=False):
     if isinstance(std, Tensor):
         std = std.item()
 
-    return Tensor(np.random.normal(mean, std, shape), dtype=dtype, constant=constant)
+    return Tensor(
+        np.random.normal(mean, std, shape),
+        dtype=dtype,
+        constant=constant,
+        copy=False,
+    )
