@@ -4,7 +4,7 @@ from mygrad import Tensor
 
 
 def uniform(*shape, lower_bound=0, upper_bound=1, dtype=np.float32, constant=None):
-    """Initialize a ``Tensor`` by drawing from a uniform distribution.
+    """Initialize a :class:`mygrad.Tensor` by drawing from a uniform distribution.
 
     Parameters
     ----------
@@ -21,7 +21,7 @@ def uniform(*shape, lower_bound=0, upper_bound=1, dtype=np.float32, constant=Non
         The data type of the output tensor; must be a floating-point type.
 
     constant : bool, optional (default=False)
-        If `True`, the returned tensor is a constant (it
+        If ``True``, the returned tensor is a constant (it
             does not back-propagate a gradient).
 
     Returns
